@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11979 2020-03-18 04:52:03Z Trista $
+# $Id: cms_plugins.py 12001 2020-03-24 16:45:06Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-03-18 12:52:03 +0800 (週三, 18 三月 2020) $
-# $Revision: 11979 $
+# $Date: 2020-03-25 01:45:06 +0900 (週三, 25 三月 2020) $
+# $Revision: 12001 $
 
 import datetime
 
@@ -270,8 +270,8 @@ plugin_pool.register_plugin(ActionForm)
 
 class CallToActionPlugin(CMSPluginBase):
     model = CallToActionModel
-    module = _("Call To Action plugin")
-    name = _("Call To Action plugin")
+    module = 'News & Blog'
+    name = _("Call To Action")
     render_template = _settings.CALL_TO_ACTION_DEFAULT_TEMPLATE
     child_classes = ['ActionForm', ]
     allow_children = True
@@ -288,7 +288,8 @@ class CallToActionPlugin(CMSPluginBase):
         # the child plugin actionform is created
         # normally it's only possible to be 1
         # obj.num_children()
-        if obj.get_children_count() >= 1:
+        # if obj.get_children_count() >= 1:
+        if CMSPlugin.objects.filter(parent_id=obj.id).exists():
             pass
             
         # the child plugin actionform is not created
@@ -306,7 +307,7 @@ class CallToActionPlugin(CMSPluginBase):
                 
                 thankNode = TreeNode(site_id=obj.page.node.site_id)
                 lan = obj.language
-                childPage = Page(node=childNode, template=_settings.THANK_DEFAULT_TEMPLATE, created_by=request.user, languages=lan)
+                childPage = Page(node=thankNode, template=_settings.THANK_DEFAULT_TEMPLATE, created_by=request.user, languages=lan)
                 childPage.save()
                 childTitle = Title(language=lan, title='Thank', slug='thank', page=childPage, path=f'{obj.page.title_set.all()[0].path}/thank')
                 childTitle.save()
@@ -326,6 +327,7 @@ class CallToActionPlugin(CMSPluginBase):
                 page_redirect=redirectPage,
                 form_template=_settings.CALL_TO_ACTION_FORM_DEFAULT_TEMPLATE,
                 plugin_reference=referencedForm,
+                email_subject=_settings.CALL_TO_ACTION_EMAIL_SUBJECT
                 # r
                 # cmsplugin_ptr_id=childPlugin.id
             )
