@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_dumpdata.py 12006 2020-03-24 18:55:57Z Trista $
+# $Id: cms_dumpdata.py 12021 2020-03-26 11:31:31Z Trista $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Trista $
-# $Date: 2020-03-25 02:55:57 +0800 (週三, 25 三月 2020) $
-# $Revision: 12006 $
+# $Date: 2020-03-26 20:31:31 +0900 (週四, 26 三月 2020) $
+# $Revision: 12021 $
 
 import os
 import sys
@@ -118,18 +118,15 @@ class Command(BaseCommand):
             
 
             path = os.path.join(options['path'])
-            
-            try:
 
-                with open(path, 'w') as f:
+            with open(path, 'w') as f:
+                try:
                     content = f.write(json.dumps(data))
-                   
-            except Exception as e:
-                os.remove(path)
-                raise e
+                except Exception as e:
+                    if os.path.exists(path):
+                        os.remove(path)
+                    raise
         
-        
-            
         finally:
         
             if os.path.exists('authData.json'):
