@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 12104 2020-04-23 05:57:59Z Lavender $
+# $Id: setup.py 12125 2020-04-26 15:56:49Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-23 14:57:59 +0900 (週四, 23 四月 2020) $
-# $Revision: 12104 $
+# $Date: 2020-04-27 00:56:49 +0900 (週一, 27 四月 2020) $
+# $Revision: 12125 $
 
 import re
 import os
@@ -59,8 +59,9 @@ logger.addHandler(handler)
 
 INTRODUCTION_URL = "https://www.django-cms-themes.com/static/docs"
 SETUP_URL = "https://www.django-cms-themes.com/static/product/assets/setup.py"
-SETUP_VERSION = "1.0.1"
+SETUP_VERSION = "1.1.0"
 SETUP_DIR = os.path.dirname(os.path.abspath(__file__))
+SETUP_SUPPORTED_CMS_VERSION = "3.7.1"
 CKEDITOR_SETTINGS = \
 '''
 CKEDITOR_SETTINGS = {
@@ -263,7 +264,7 @@ def copyToPath(baseDir, templateDir, staticDir, mode):
 def findSettings(path):
     for root, dirs, files in os.walk(path):
         for f in files:
-            if f == 'settings.py':
+            if f == 'settings.py' and "urls.py" in files and "wsgi.py" in files:
                 return os.path.join(root, f)
     return None
    
@@ -576,10 +577,10 @@ if __name__ == "__main__":
                 
             cmsVersion = data["DjangoCMSVersion"]
         else:
-            cmsVersion = '3.7.0'
+            cmsVersion = '3.7.1'
             
-        # default
-        cmsVersion = '3.7.0'
+        # default for setup.py
+        cmsVersion = '3.7.1'
         
         if cmsVersion.startswith("3.6"):
             installVersion = "1.2.0"
@@ -590,6 +591,26 @@ if __name__ == "__main__":
             logger.warning(colored(
                 "Not support django-cms<3.6", "yellow"))
             sys.exit(1)
+        
+        # check cms version
+        try:
+            import cms
+            cmsVersion = cms.__version__
+            if cmsVersion.split(".") > SETUP_SUPPORTED_CMS_VERSION.split("."):
+                logger.warning(colored(
+                    ("The version of cms installed in your virtual environment is %s, "
+                     "but setup.py only supported django-cms<=%s. "
+                     "Try to install django-cms<=%s.") % (
+                     cmsVersion, SETUP_SUPPORTED_CMS_VERSION, SETUP_SUPPORTED_CMS_VERSION), "yellow"))
+                os.system("pip install \"django-cms<=%s\"" % SETUP_SUPPORTED_CMS_VERSION)
+        except Exception as e:
+            logger.warning(colored(
+                "You aren't install django-cms. Try to install django-cms<=%s." % SETUP_SUPPORTED_CMS_VERSION, "yellow")
+            )
+            os.system("pip install \"django-cms<=%s\"" % SETUP_SUPPORTED_CMS_VERSION)
+            import cms
+            
+        cmsVersion = cms.__version__
             
         sendLog({
             "level": "INFO",
@@ -680,7 +701,7 @@ if __name__ == "__main__":
         else:
             path = os.path.dirname(os.path.dirname(settingsPath))
         
-        if len(path) == 0:
+        if not path:
             settingModule = os.path.splitext(settingsPath)[0]
         else:
             settingModule = os.path.splitext(settingsPath[len(path) + 1:])[0]
@@ -688,21 +709,10 @@ if __name__ == "__main__":
         settingModule = settingModule.replace("\\", ".")
         
         sys.path.append(path)
-        os.environ['DJANGO_SETTINGS_MODULE'] = settingModule        
-        
-        try:
-            import cms
-        except Exception as e:
-            os.system("pip install django-cms==%s" % cmsVersion)
-            import cms
+        os.environ['DJANGO_SETTINGS_MODULE'] = settingModule    
+
+        cmsVersion = cms.__version__.split('.')
 
-        if cms.__version__.startswith('3.5'):
-            try:
-                import cmsplugin_filer_image
-            except Exception as e:
-                os.system("pip install cmsplugin-filer==1.1.3")
-                import cms
-                
         import django
          
         if django.VERSION <= (2, 0): 
@@ -726,11 +736,9 @@ if __name__ == "__main__":
                     colored("Can't install djangocms_text_ckeditor==3.8.0", 
                             "red"))
                 sys.exit(1)
-           
-        cmsVersion = cms.__version__.split('.')
        
         django.setup()
-       
+        
         from django.conf import settings
        
         baseDir = settings.BASE_DIR
