@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 12044 2020-04-05 11:36:35Z Lavender $
+# $Id: cms_plugins.py 12126 2020-04-27 12:30:33Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-04-05 20:36:35 +0900 (週日, 05 四月 2020) $
-# $Revision: 12044 $
+# $Date: 2020-04-27 21:30:33 +0900 (週一, 27 四月 2020) $
+# $Revision: 12126 $
 
 import re
 import requests
@@ -66,7 +66,8 @@ def getAccessToken():
         # settings.SOCIAL_AUTH_FACEBOOK_KEY, 
         # settings.SOCIAL_AUTH_FACEBOOK_SECRET
     # )
-    return FacebookSettings.objects.get().accessToken
+    config, created = FacebookSettings.objects.get_or_create()
+    return config.accessToken
     
 def getAuthorizationMsg():
     popScript = '''
