@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: middleware.py 11869 2020-01-14 14:23:13Z Lavender $
+# $Id: middleware.py 11984 2020-03-19 12:21:32Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-01-14 22:23:13 +0800 (週二, 14 一月 2020) $
-# $Revision: 11869 $
+# $Date: 2020-03-19 21:21:32 +0900 (週四, 19 三月 2020) $
+# $Revision: 11984 $
 
 import re
 
@@ -22,8 +22,11 @@ from django.http import HttpResponse
 from django.utils.deprecation import MiddlewareMixin
 
 from Iuppiter.DjangoUtil import DJANGO_VERSION
+from Iuppiter.Logging import createLogger
 from Zephyrus.statistics.models import URL
 
+logger = createLogger(__name__)
+
 if hasattr(settings, 'ZEPHYRUS_STATISTICS_URL_INCLUDE'):
     ZEPHYRUS_STATISTICS_URL_INCLUDE = settings.ZEPHYRUS_STATISTICS_URL_INCLUDE
 else:
@@ -41,30 +44,33 @@ else:
     
 class StatisticsMiddleware(MiddlewareMixin):
     def process_request(self, request):
-        # match
-        path2 = request.path[1:] # 去掉網址最前面的 /
-        
-        if ZEPHYRUS_STATISTICS_URL_INCLUDE:
-            needRecord = False
-            for pattern in ZEPHYRUS_STATISTICS_URL_INCLUDE:
-                if pattern.search(path2):
-                    needRecord = True
-        else:
-            # default 
-            needRecord = True
-        
-        for pattern in ZEPHYRUS_STATISTICS_URL_EXCLUDE:
-            if pattern.search(path2):
+        try:
+            # match
+            path2 = request.path[1:] # 去掉網址最前面的 /
+            
+            if ZEPHYRUS_STATISTICS_URL_INCLUDE:
                 needRecord = False
+                for pattern in ZEPHYRUS_STATISTICS_URL_INCLUDE:
+                    if pattern.search(path2):
+                        needRecord = True
+            else:
+                # default 
+                needRecord = True
+            
+            for pattern in ZEPHYRUS_STATISTICS_URL_EXCLUDE:
+                if pattern.search(path2):
+                    needRecord = False
 
-        # view count
-        if needRecord:
-            url = request.build_absolute_uri(request.path)
-            obj, created = URL.objects.get_or_create(
-                url=url,
-            )
-            obj.viewCount += 1
-            obj.save()
+            # view count
+            if needRecord:
+                url = request.build_absolute_uri(request.path)
+                obj, created = URL.objects.get_or_create(
+                    url=url,
+                )
+                obj.viewCount += 1
+                obj.save()
+        except Exception as e:
+            logger.error(str(e))
         return None
  
     def process_response(self, request, response):
